/* qddb/Headers/Globals.h
 *
 * Copyright (C) 1993, 1994 Herrin Software Development, Inc.
 * All rights reserved.
 *
 * This file is part of Qddb.
 *
 * Qddb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2
 * as published by the Free Software Foundation.
 *
 * Qddb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qddb; see the file LICENSE.  If not, write to:
 *
 *	Herrin Software Development, Inc. 
 *	R&D Division
 *	41 South Highland Ave. 
 *	Prestonsburg, KY 41653 
 */

#if !defined(_QDDB_GLOBALS_H_)
#define _QDDB_GLOBALS_H_

/* qddb_errno values 
 */
#define QDDB_ERRNO_INVALID_ARG		0x0001
#define QDDB_ERRNO_INVALID_REGEXP	0x0002
#define QDDB_ERRNO_PARSE_ERROR		0x0004
#define QDDB_ERRNO_MALFORMED_ATTR	0x0008
#define QDDB_ERRNO_WRLOCKED		0x0010
#define QDDB_ERRNO_NEEDSTAB		0x0020

extern int qddb_errno;
extern char *qddb_errmsg;
extern int qddb_stabilizing;
extern int qddb_maxmem;
extern int qddb_maxfiles;
extern char *qddb_default_date_format;
extern int qddb_datestyle;
#endif
